import { useRef, useState, useEffect } from 'react'
import { Center, Heading, Input, Stack, Text, useColorMode, Button, Icon, InputGroup, InputLeftElement } from "@chakra-ui/react"
import "./App.css"
import ThemeButton from './Components/ThemeButton';
import TimeGreeting from './utils/TimeGreeting';
import { TimeIcon } from '@chakra-ui/icons';
import FrequentlyVisited from './Components/FrequentlyVisited';
import BookMarks from './Components/BookMarks';
import useDebounce from './Hooks/useDebounce';
import SuggestSearch from './utils/SearchSuggestion'
import Suggestion from './Components/Suggestion';
import isUrl from './utils/isUrl';

import { AiFillYoutube } from "react-icons/ai"
import IpFooter from './Components/ipFooter';

function App() {
  const inputRef = useRef(null);
  const [currentTime, setCurrentTime] = useState(getTime())
  const { colorMode } = useColorMode();

  const [search, setSearch] = useState(null);
  const [suggestions, setSuggestions] = useState([]);

  const [searchYt, setSearchYt] = useState(false);
  const [searchLocal, setSearchLocal] = useState(false);

  const [allowBookmarks, setAllowBookmarks] = useState(false);

  function keyPress(event) {
    if (event.code === "Enter") {
      let search = inputRef.current.value;
      if (search === " " || search == "") return;
      if (searchLocal) {
        window.location.href = "http://localhost:" + search
        return;
      }
      if (isUrl(search)) {
        if (!search.startsWith("http")) {
          search = `https://${search}`;
        }
        window.location.href = search;
      } else {
        window.location.href = `https://google.com/search?q=${search}`
      }
    }
  }
  function getTime() {
    const date = new Date();
    const format = `${date.toDateString()} • ${date.toTimeString().split(" ")[0]}`
    return format;
  }

  setTimeout(() => {
    setCurrentTime(getTime());
  }, 1000);

  useEffect(() => {
    inputRef.current.select();
  }, [])

  const handleChange = (event) => {
    setSearch(event.target.value)
  }

  let debouncedSearch = useDebounce(search, 500);

  useEffect(() => {
    let url;
    if (!debouncedSearch) {
      setSuggestions([])
      return
    };
    if (searchLocal) return;
    console.log(debouncedSearch)
    if (debouncedSearch.startsWith("yt") || debouncedSearch.startsWith("youtube")) {
      setSearchYt(true);
      inputRef.current.value = inputRef.current.value.replace("yt", "")
      inputRef.current.value = inputRef.current.value.replace("youtube", "")
      debouncedSearch = debouncedSearch.replace("youtube", "")
      debouncedSearch = debouncedSearch.replace("yt", "")
      url = `https://api.jamesz.dev/search-query?query=${debouncedSearch}&platform=yt`
    } else if (debouncedSearch.startsWith("localhost") || debouncedSearch.startsWith("local")) {
      setSearchLocal(true);
      inputRef.current.value = inputRef.current.value.replace("localhost", "")
      inputRef.current.value = inputRef.current.value.replace("local", "")
      debouncedSearch = debouncedSearch.replace("localhost", "")
      debouncedSearch = debouncedSearch.replace("local", "")
      setSuggestions(["3000", "5173", "5000"])
      return;
    } else {
      url = `https://api.jamesz.dev/search-query?query=${debouncedSearch}&platform=g`
    }

    // const url = `https://api.jamesz.dev/search-query?query=${debouncedSearch}&platform=${searchYt ? "yt" : "g"}`

    fetch(url)
    .then(response => response.json())
    .then(data => {
        setSuggestions(data.suggestions.slice(0, 5))
    })

  }, [debouncedSearch])
  
  const offYt = () => {
    setSuggestions([])
    setSearchYt(false)
  }
  const offLocal = () => {
    setSuggestions([])
    setSearchLocal(false)
  }

  return (
    <>
      <ThemeButton />
      <Center>
      <Stack>
        <Heading>{TimeGreeting}</Heading>
        <Text color={colorMode === "dark" ? "gray.400" : "gray.700"}><TimeIcon mr={2}/>{currentTime}</Text>

        <InputGroup mt={5}>

          {searchYt ? (
            <InputLeftElement width='2.5rem'>
              <Button h='1.75rem' size='sm' onClick={() => offYt()}>
                <Icon as={AiFillYoutube} fontSize="x-large" />
              </Button>
            </InputLeftElement>

            ) : null
          }
          {searchLocal ? (
            <InputLeftElement width='4.5rem'>
              <Button h='1.75rem' size='sm' onClick={() => offLocal()}>
                localhost:
              </Button>
            </InputLeftElement>

            ) : null
          }
          <Input placeholder={searchLocal ? "" : 'Search the web...'} onKeyDown={keyPress} ref={inputRef} w="500px" onChange={handleChange} bgColor={colorMode === "dark" ? "gray.900" : "gray.300"} />
        </InputGroup>

        {suggestions.map(suggestion => (
          <Suggestion text={suggestion} isYt={searchYt} isLoc={searchLocal} />
        ))}

        {allowBookmarks ? (
          <>
          <FrequentlyVisited />
  
          <BookMarks />
          </>
        ) : null}


      </Stack>
      </Center>
      <IpFooter setAllowBookmarks={setAllowBookmarks} />
    </>
  )
}

export default App
