import React from "react";
import { Heading, useColorMode, Box, Avatar, Text, useDisclosure, Grid, GridItem, Icon, Divider, Link } from "@chakra-ui/react";
import { ChevronDownIcon, ChevronRightIcon, MoonIcon, SunIcon } from '@chakra-ui/icons';
import { IoMdSchool } from "react-icons/io"
import { HiCode } from "react-icons/hi"
import { BsEggFried } from "react-icons/bs"
import { GrDocument } from "react-icons/gr"

function BookMarks() {
  const { colorMode, toggleColorMode } = useColorMode();
  const { isOpen, onToggle } = useDisclosure();

  const sections = [{name: "University", icon: IoMdSchool}, {name: "Coding", icon: HiCode}, {name: "Documentation", icon: GrDocument}, {name: "Misc", icon: BsEggFried} ]

  const links = [
    {
        name: "DCU Loop",
        url: "https://loop.dcu.ie/",
        section: "University"

    },
    {
        name: "DCU Mail",
        url: "https://mail.google.com/mail/u/4/#inbox",
        section: "University"
    },
    {
        name: "CA116 Website",
        url: "https://ca116.computing.dcu.ie/",
        section: "University"
    },
    {
        name: "Einstein",
        url: "https://ca116.computing.dcu.ie/einstein/",
        section: "University"
    },
    {
        name: "DCU Timetable",
        url: "https://mytimetable.dcu.ie/timetables?view=week&timetableTypeSelected=241e4d36-60e0-49f8-b27e-99416745d98d&searchText=com&selections=241e4d36-60e0-49f8-b27e-99416745d98d__db214724-e16c-82a1-8b07-5edb97d78f2d/",
        section: "University"
    },
    {
        name: "TermCast",
        url: "https://termcast.computing.dcu.ie/",
        section: "University"
    },
    {
        name: "GitLab",
        url: "https://git.pogr.cc/",
        section: "Coding"
    },
    {
        name: "Cloudflare",
        url: "https://dash.cloudflare.com/",
        section: "Coding"
    },
    {
        name: "AuthServices",
        url: "https://auth.pogr.cc/",
        section: "Coding"
    },
    {
        name: "Pogr.cc",
        url: "https://pogr.cc/",
        section: "Coding"
    },
    {
        name: "Vikunja",
        url: "https://notes.jamesz.dev/",
        section: "Coding"
    },
    {
        name: "ChakraUI Docs",
        url: "https://chakra-ui.com/",
        section: "Documentation"
    },
    {
        name: "React Icons",
        url: "https://react-icons.github.io/react-icons",
        section: "Documentation"
    },
  ]

  const redirect = (url) => {
    window.location.href = url;
  }

  return (
    <>  
        <Text onClick={onToggle} cursor="pointer" className="no-highlight" mt={10}>{isOpen ? <ChevronDownIcon/> : <ChevronRightIcon/>} Show all bookmarks... </Text>
        <div className={isOpen ? "" : "hidden"}>
        <Grid templateColumns='repeat(5, 1fr)' gap={6}>
            {sections.map(section => (
                <GridItem w='100%' h='10'>
                    <Heading size="md"><Icon as={section.icon} mt={1} mr={1} />{section.name}</Heading>
                    <Divider mt={2} mb={3} />
                    {/* <Divider height=".5em" color="white" border="none" m={2} /> */}
                    {links.map(link => {
                        if (link.section === section.name) {
                            return <Text><Link href={link.url}>{link.name}</Link></Text>
                        }
                    })}    
                </GridItem>
            ))}
        </Grid>
        </div>

    </>
  );
}

export default BookMarks;
