import { Box, Button, Text } from '@chakra-ui/react'
import React, { useEffect, useState } from 'react'
import { BsEye } from 'react-icons/bs'

export default function IpFooter({setAllowBookmarks}) {
    const [currentIp, setCurrentIp] = useState("--")
    const [onEllieNet, setOnEllieNet] = useState(false)
    const [showDetails, setShowDetails] = useState(false)

    const loadHideDetails = () => {
        const saved = localStorage.getItem("showDetails") || false;
        if (saved === "true") {
            setShowDetails(true);
        }
    }

    const toggleHideDetails = () => {
        if (showDetails) {
            localStorage.setItem("showDetails", false)
            setShowDetails(false);
        } else {
            localStorage.setItem("showDetails", true);
            setShowDetails(true);
        }
    }

    const getIp = () => {
        fetch("https://api.ipify.org?format=json")
          .then((response) => response.json())
          .then((data) => {
            setCurrentIp(data.ip); // Set the IP address
          })
          .catch((error) => console.error("Error fetching IP:", error));
    }

    const checkIfOnNet = async () => {
        
        try {
            const response = await fetch("https://pass.elliee.me", {
              method: "HEAD", // Use HEAD to reduce data transfer
              mode: "no-cors", // Allow network request without expecting a response
            });
    
            // If no error occurs, we assume the network is reachable
            setOnEllieNet(true);
            setAllowBookmarks(true)
        } catch (error) {
            // If there's an error, we assume the network is not reachable
            setOnEllieNet(false);
        }
    }

    useEffect(() => {
        loadHideDetails();
        getIp();
        checkIfOnNet();
    }, []);


    return (
        <>
            <Box
                position="fixed"
                bottom={1}
                left={1}
                display="flex"
                flexDir="row"
            >
                <Text hidden={!showDetails}>Your IP: {currentIp}</Text>
                <Text marginLeft=".4em" hidden={!showDetails}>•</Text>
                <Text marginLeft=".4em" color={onEllieNet ? "green" : "red"}>{onEllieNet ? "✓" : "✗"}</Text>
                <Text marginLeft=".2em">EllieNet</Text>

                <Button variant="ghost" size="xs" marginLeft=".2em" onClick={toggleHideDetails}><BsEye /></Button>
            </Box>
        </>
    )
}
